==> radiusd-cistron-1.5.3.tar.gz: radiusd-cistron-1.5.3/src/radutmp.h <==
/*
 * radutmp.h	Definitions for the Radius UTMP file.
 *
 * Version:	@(#)radutmp  2.00  30-Jul-1996  MvS.
 */

#ifndef _RADUTMP_H
#define _RADUTMP_H

#define RADUTMP "/var/log/radutmp"
#define RADWTMP "/var/log/radwtmp"

/*
 *      Types of connection.
 */
#ifndef P_UNKNOWN
#  define P_UNKNOWN       0
#  define P_LOCAL         'L'
#  define P_RLOGIN        'R'
#  define P_SLIP          'S'
#  define P_CSLIP         'C'
#  define P_PPP           'P'
#  define P_AUTOPPP       'A'
#  define P_TELNET        'E'
#  define P_TCPCLEAR      'T'
#  define P_TCPLOGIN      'U'
#  define P_CONSOLE       '!'
#  define P_SHELL         'X'
#endif

#define P_IDLE		0
#define P_LOGIN		1

#if 0

/*
 *	Old structures - not used anymore.
 */
#define RUT_HOSTSIZE 32
#define RUT_NAMESIZE 16
#define RUT_LINESIZE 12
#define RUT_SERVSIZE 32

struct radutmp {
  char ut_name[RUT_NAMESIZE];  /* Loginname */
  char ut_host[RUT_HOSTSIZE];  /* Hostname [dynamic IP address] */
  char ut_line[RUT_LINESIZE];  /* port id */
  char ut_serv[RUT_SERVSIZE];  /* Name of terminal server. */
  char ut_id[4];               /* Ppp, Slip, Terminal */
  time_t ut_time;              /* Start of login. */
};

#else

#define RUT_NAMESIZE 32

struct radutmp {
  char login[32];		/* Loginname */
  int  nas_port;		/* Port on the terminal server (32 bits). */
  char session_id[8];		/* Radius session ID (first 8 bytes at least)*/
  unsigned int nas_address;	/* IP of portmaster. */
  unsigned int framed_address;	/* SLIP/PPP address or login-host. */
  int proto;			/* Protocol. */
  time_t time;			/* Time entry was last updated. */
  time_t delay;			/* Delay time of request */
  int type;			/* Type of entry (login/logout) */
  char reserved[32];		/* 8 ints reserved */
};

#endif /* RADUTMP_VER */

#endif /* _RADUTMP_H */

==> radiusd-cistron_1.6.6.orig.tar.gz: radiusd-cistron-1.6.6/src/radutmp.h <==
/*
 * radutmp.h	Definitions for the Radius UTMP file.
 *
 *		Copyright 1998 Cistron Internet Services B.V.
 *
 * Version:	$Id: radutmp.h,v 1.2 2000/12/01 16:13:23 miquels Exp $
 */

#ifndef _RADUTMP_H
#define _RADUTMP_H

/*
 *      Types of connection.
 */
#ifndef P_UNKNOWN
#  define P_UNKNOWN       0
#  define P_LOCAL         'L'
#  define P_RLOGIN        'R'
#  define P_SLIP          'S'
#  define P_CSLIP         'C'
#  define P_PPP           'P'
#  define P_AUTOPPP       'A'
#  define P_TELNET        'E'
#  define P_TCPCLEAR      'T'
#  define P_TCPLOGIN      'U'
#  define P_CONSOLE       '!'
#  define P_SHELL         'X'
#endif

#define P_IDLE		0
#define P_LOGIN		1

#define RUT_NAMESIZE 32

struct radutmp {
  char login[32];		/* Loginname */
				/* FIXME: extend to 48 or 64 bytes */
  int  nas_port;		/* Port on the terminal server (32 bits). */
  char session_id[8];		/* Radius session ID (first 8 bytes at least)*/
				/* FIXME: extend to 16 or 32 bytes */
  unsigned int nas_address;	/* IP of portmaster. */
  unsigned int framed_address;	/* SLIP/PPP address or login-host. */
  int proto;			/* Protocol. */
  time_t time;			/* Time entry was last updated. */
  time_t delay;			/* Delay time of request */
  int type;			/* Type of entry (login/logout) */
  char porttype;		/* Porttype (I=ISDN A=Async T=Async-ISDN */
  char res1,res2,res3;		/* Fills up to one int */
  char caller_id[16];		/* Calling-Station-ID */
  char reserved[12];		/* 3 ints reserved */
};

#endif /* _RADUTMP_H */
